/**
 * Copyright 2011 - InvestLab Technologies, Ltd. All rights reserved.
 *
 * User: Dave
 * Date: 2/28/11
 * Time: 4:25 PM
 */
package test

import scala.collection.JavaConversions._

import org.infinispan.Cache
import org.infinispan.manager.{DefaultCacheManager}
import org.infinispan.config.{CacheLoaderManagerConfig, Configuration}
import org.infinispan.loaders.cassandra.CassandraCacheStoreConfig
import org.infinispan.loaders.CacheLoaderConfig


object CacheLoaderTest {

   def main(args:Array[String]) {

      val manager = new DefaultCacheManager( createConfiguration)
      val cache: Cache[String,String] = manager.getCache("InvestLab")

      cache.put("key1", "Hello")
      cache.put("key2", "World")

      cache.stop
      manager.stop
   }

   def createConfiguration() : Configuration = {

      val ccs = new CassandraCacheStoreConfig
      ccs.setFetchPersistentState   (true)
      ccs.setIgnoreModifications    (false)
      ccs.setPurgeOnStartup         (false)
      ccs.setHost                   ("localhost")
      ccs.setKeySpace               ("Infinispan")
      ccs.setEntryColumnFamily      ("InfinispanEntries")
      ccs.setExpirationColumnFamily ("InfinispanExpiration")
      ccs.setSharedKeyspace         (false)
      ccs.setReadConsistencyLevel   ("ONE")
      ccs.setWriteConsistencyLevel  ("ONE")
      ccs.setConfigurationPropertiesFile("cassandrapool.properties")
      ccs.setKeyMapper              ("org.infinispan.loaders.keymappers.DefaultTwoWayKey2StringMapper")

      val loaders = ccs :: Nil
      val cm = new CacheLoaderManagerConfig
      cm.setPassivation(false)
      cm.setShared(true)
      cm.setPreload(false)
      cm.setCacheLoaderConfigs(loaders)

      val cfg = new Configuration
      cfg.setCacheLoaderManagerConfig( cm)

      cfg
   }
}

/**
<namedCache name="cassandraCache">
        <loaders passivation="false" shared="true" preload="false">
                <loader class="org.infinispan.loaders.cassandra.CassandraCacheStore"
                        fetchPersistentState="true"
                        ignoreModifications="false"
                        purgeOnStartup="false">
                        <properties>
                                <property name="host" value="localhost" />
                                <property name="keySpace" value="Infinispan" />
                                <property name="entryColumnFamily" value="InfinispanEntries" />
                                <property name="expirationColumnFamily" value="InfinispanExpiration" />
                                <property name="sharedKeyspace" value="false" />
                                <property name="readConsistencyLevel" value="ONE" />
                                <property name="writeConsistencyLevel" value="ONE" />
                                <property name="configurationPropertiesFile" value="cassandrapool.properties" />
                                <property name="keyMapper" value="org.infinispan.loaders.keymappers.DefaultTwoWayKey2StringMapper" />
                        </properties>
                </loader>
        </loaders>
</namedCache>
**/